@@ -535,6 +535,25 @@ def get_local_file_information(
             all_paths
         )
 
+        # Python glob behaves differently than Python fnmatch, where glob will
+        # ignore file names beginning with period (dot) unless specifically
+        # sought. For cases where the trailing search pattern is * or **,
+        # perform a search for ".*" to pick up dot files.
+        src_dir_wc_dot_search = None
+        src_dir_wc_parent, src_dir_wc_trailing = os.path.split(src_dir_wc)
+        if src_dir_wc_trailing == "**":
+            # Append ".*" resulting in "<parents>/**/.*".
+            src_dir_wc_dot_search = os.path.join(src_dir_wc, ".*")
+        elif src_dir_wc_trailing == "*":
+            # Replace "*" resulting in "<parents>/.*".
+            src_dir_wc_dot_search = os.path.join(src_dir_wc_parent, ".*")
+        if src_dir_wc_dot_search is not None:
+            discovered.update(
+                set(
+                    iglob(pathname=src_dir_wc_dot_search, recursive=True)
+                ).difference(all_paths)
+            )
+
         # Refine further, retaining only files which are not ignored.
         discovered = [v for v in discovered if os.path.isfile(v) and not is_ignored(v)]
 
